@@ -1,11 +1,15 @@
 import re
+import warnings
 
 from django import template
+from django.utils.html import conditional_escape
+from django.utils.safestring import mark_safe
 
-from comment.models import ReactionInstance, FlagInstance, Follower
+from comment.models import ReactionInstance, FlagInstance, Follower, BlockedUser
 from comment.forms import CommentForm
 from comment.utils import (
-    is_comment_moderator, is_comment_admin, get_gravatar_img, get_profile_instance, get_wrapped_words_number
+    is_comment_moderator, is_comment_admin, get_gravatar_img, get_profile_instance, get_wrapped_words_number,
+    can_block_user
 )
 from comment.managers import FlagInstanceManager
 from comment.messages import ReactionError
@@ -87,15 +91,21 @@ def render_comments(obj, request, oauth=False):
 register.inclusion_tag('comment/base.html')(render_comments)
 
 
+def _restrict_line_breaks(content):
+    # Restrict 2 or more line breaks to 2 <br>
+    content = MULTIPLE_NEW_LINE_RE.sub(r'\1<br><br>\3', content)
+    return SINGLE_NEW_LINE_RE.sub(r'\1<br>\3', content)
+
+
 def render_content(comment, number=None):
     try:
         number = int(number)
     except (ValueError, TypeError):
         number = get_wrapped_words_number()
 
-    # Restrict 2 or more line breaks to 2 <br>
-    content = MULTIPLE_NEW_LINE_RE.sub(r'\1<br><br>\3', comment.content)
-    content = SINGLE_NEW_LINE_RE.sub(r'\1<br>\3', content)
+    # this is necessary to avoid XSS attacks
+    escaped_content = conditional_escape(comment.content)
+    content = _restrict_line_breaks(escaped_content)
     content_words = content.split()
     if not number or len(content_words) <= number:
         text_1 = content
@@ -105,23 +115,42 @@ def render_content(comment, number=None):
         text_2 = ' '.join(content_words[number:])
 
     return {
-        'text_1': text_1,
-        'text_2': text_2,
+        'text_1': mark_safe(text_1),
+        'text_2': mark_safe(text_2) if text_2 else None,
         'urlhash': comment.urlhash
     }
 
 
+register.inclusion_tag('comment/comments/content.html')(render_content)
+
+
 @register.simple_tag(name='can_delete_comment')
 def can_delete_comment(comment, user):
     return is_comment_admin(user) or (comment.is_flagged and is_comment_moderator(user))
 
 
-register.inclusion_tag('comment/comments/content.html')(render_content)
+@register.filter(name='can_block_users')
+def can_block_users_tag(user):
+    return can_block_user(user)
 
 
+@register.filter(name='is_user_blocked')
+def is_user_blocked(comment):
+    user_id = comment.user.id if comment.user else None
+    return BlockedUser.objects.is_user_blocked(user_id, comment.email)
+
+
+# TODO: remove in v3.0.0
 @register.simple_tag(name='include_static')
 def include_static():
     """ This function shall be deprecated """
+    warnings.warn(
+        (
+            'The tag `include_static` has been deprecated. Static files are now rendered implicitly.'
+            'You can remove this from your django template. This tag will be removed in v3.0.0.'
+        ),
+        DeprecationWarning
+    )
     return ''
 
 
