@@ -74,8 +74,12 @@ def has_valid_profile():
     return False
 
 
+def _is_moderation_enabled():
+    return settings.COMMENT_FLAGS_ALLOWED or settings.COMMENT_ALLOW_BLOCKING_USERS
+
+
 def is_comment_admin(user):
-    if settings.COMMENT_FLAGS_ALLOWED:
+    if _is_moderation_enabled():
         return user.groups.filter(name="comment_admin").exists() or (
             user.has_perm("comment.delete_flagged_comment")
             and user.has_perm("comment.delete_comment")
@@ -84,13 +88,31 @@ def is_comment_admin(user):
 
 
 def is_comment_moderator(user):
-    if settings.COMMENT_FLAGS_ALLOWED:
+    if _is_moderation_enabled():
         return user.groups.filter(name="comment_moderator").exists() or user.has_perm(
             "comment.delete_flagged_comment"
         )
     return False
 
 
+def can_moderate_flagging(user):
+    return bool(
+        settings.COMMENT_FLAGS_ALLOWED and
+        (is_comment_admin(user) or is_comment_moderator(user))
+    )
+
+
+def can_moderator_block_users(moderator):
+    return settings.COMMENT_ALLOW_MODERATOR_TO_BLOCK and is_comment_moderator(moderator)
+
+
+def can_block_user(user):
+    return bool(
+        settings.COMMENT_ALLOW_BLOCKING_USERS and
+        (is_comment_admin(user) or can_moderator_block_users(user))
+    )
+
+
 def paginate_comments(comments, comments_per_page, current_page):
     paginator = Paginator(comments, comments_per_page)
     try:
